extra library

Enums

Format
This enum provides a set of commonly used formats that can be paired with a type to give a more specific hint about the data's intended structure and validation rules.
HttpMethod
HTTP methods supported in an OpenAPI definition.
OpenApiVersion
Supported versions of the OpenAPI specification.
ParameterLocation
The location of a parameter in an OpenAPI operation.

Functions

intOrNull(dynamic value) int?
Converts value to an int if possible, otherwise returns null.
numOrNull(dynamic value) num?
Converts value to a num if possible, otherwise returns null.