HttpMethod enum

HTTP methods supported in an OpenAPI definition.

Inheritance
Available extensions

Values

get → const HttpMethod

HTTP GET request (retrieves data).

post → const HttpMethod

HTTP POST request (creates a resource).

put → const HttpMethod

HTTP PUT request (replaces a resource).

delete → const HttpMethod

HTTP DELETE request (removes a resource).

patch → const HttpMethod

HTTP PATCH request (partially updates a resource).

HTTP HEAD request (retrieves headers only).

options → const HttpMethod

HTTP OPTIONS request (retrieves available methods).

trace → const HttpMethod

HTTP TRACE request (used for debugging).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<HttpMethod>
A constant List of the values in this enum, in order of their declaration.