ParameterLocation enum

The location of a parameter in an OpenAPI operation.

Inheritance
Available extensions

Values

query → const ParameterLocation

Parameter is appended to the query string of the URL.

Parameter is passed in the request header.

path → const ParameterLocation

Parameter is part of the URL path.

Parameter is stored in an HTTP cookie.

body → const ParameterLocation

Parameter is included in the request body.

Note: Valid only in OpenAPI 2.0 (Swagger).

formData → const ParameterLocation

Parameter is provided as form data.

Note: Valid only in OpenAPI 2.0 (Swagger).

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromString(String value) ParameterLocation
Creates a ParameterLocation from a string value.

Constants

values → const List<ParameterLocation>
A constant List of the values in this enum, in order of their declaration.