v20 library

A comprehensive library for working with OpenAPI 2.0 (Swagger) documents.

Classes

Contact
Represents the contact information for the API.
Discriminator
The Discriminator Object gives a hint about the expected schema of the document when request bodies or response payloads may be one of a number of different schemas.
ExternalDocs
Represents external documentation for the API.
Represents a response header definition.
Info
Represents the metadata about the API.
License
Represents the license information for the API.
MediaType
Describes a single media type object, such as 'application/json' or 'image/png'.
OpenAPI
The root document object of the OpenAPI 2.0 (Swagger) specification.
OpenAPiParser
Utility class to parse OpenAPI specs
Operation
Describes a single API operation on a path.
PathItem
Describes the operations available on a single path. A Path Item MAY be empty, due to ACL constraints. The path itself is still exposed to the documentation viewer but they will not know which operations and parameters are available.
RequestBody
Describes a single request body.
Response
Describes a single API response.
Schema
The Schema Object allows the definition of input and output data types for OpenAPI 2.0.
SecurityRequirement
Represents a Security Requirement Object in OpenAPI/Swagger 2.0.
SecurityScheme
Represents a single security scheme object for OpenAPI 2.0.
Server
An object representing a Server.
Tag
Represents a tag used for grouping API operations.
Xml
Describes the XML representation of an object.

Extensions

ContactPatterns on Contact
Adds pattern-matching-related methods to Contact.
DiscriminatorPatterns on Discriminator
Adds pattern-matching-related methods to Discriminator.
ExternalDocsPatterns on ExternalDocs
Adds pattern-matching-related methods to ExternalDocs.
HeaderPatterns on Header
Adds pattern-matching-related methods to Header.
InfoPatterns on Info
Adds pattern-matching-related methods to Info.
LicensePatterns on License
Adds pattern-matching-related methods to License.
MediaTypePatterns on MediaType
Adds pattern-matching-related methods to MediaType.
OpenAPIPatterns on OpenAPI
Adds pattern-matching-related methods to OpenAPI.
OperationPatterns on Operation
Adds pattern-matching-related methods to Operation.
PathItemPatterns on PathItem
Adds pattern-matching-related methods to PathItem.
RequestBodyPatterns on RequestBody
Adds pattern-matching-related methods to RequestBody.
ResponsePatterns on Response
Adds pattern-matching-related methods to Response.
SchemaPatterns on Schema
Adds pattern-matching-related methods to Schema.
SecuritySchemePatterns on SecurityScheme
Adds pattern-matching-related methods to SecurityScheme.
ServerPatterns on Server
Adds pattern-matching-related methods to Server.
TagPatterns on Tag
Adds pattern-matching-related methods to Tag.
XmlPatterns on Xml
Adds pattern-matching-related methods to Xml.