email property

String? get email
inherited

The email address of the contact person or organization.

Implementation

String? get url;/// The email address of the contact person or organization.
String? get email;