securityDefinitions property

Map<String, SecurityScheme> get securityDefinitions
inherited

A declaration of security schemes used in the API.

Implementation

Map<String, Schema> get definitions;/// A declaration of security schemes used in the API.
Map<String, SecurityScheme> get securityDefinitions;