OperationPatterns extension

Adds pattern-matching-related methods to Operation.

on

Methods

map<TResult extends Object?>(TResult $default(_Operation value)) → TResult

Available on Operation, provided by the OperationPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Operation value)?) → TResult?

Available on Operation, provided by the OperationPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Operation value)?, {required TResult orElse()}) → TResult

Available on Operation, provided by the OperationPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(List<String> tags, String? summary, String? description, String? operationId, List<Parameter> parameters, RequestBody? requestBody, Map<String, Response> responses, List<SecurityRequirement> security, List<String>? consumes, List<String>? produces, bool? deprecated)?, {required TResult orElse()}) → TResult

Available on Operation, provided by the OperationPatterns extension

A variant of when that fallback to an orElse callback.
when<TResult extends Object?>(TResult $default(List<String> tags, String? summary, String? description, String? operationId, List<Parameter> parameters, RequestBody? requestBody, Map<String, Response> responses, List<SecurityRequirement> security, List<String>? consumes, List<String>? produces, bool? deprecated)) → TResult

Available on Operation, provided by the OperationPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(List<String> tags, String? summary, String? description, String? operationId, List<Parameter> parameters, RequestBody? requestBody, Map<String, Response> responses, List<SecurityRequirement> security, List<String>? consumes, List<String>? produces, bool? deprecated)?) → TResult?

Available on Operation, provided by the OperationPatterns extension

A variant of when that fallback to returning null