ref property
A reference to a Parameter Object, typically in the components
section. If this field is non-null, all other fields must be null.
Implementation
@JsonKey(name: r'$ref') String? get ref;
A reference to a Parameter Object, typically in the components
section. If this field is non-null, all other fields must be null.
@JsonKey(name: r'$ref') String? get ref;