OpenAPiParser class
Utility class to parse OpenAPI specs
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
parseJson(
String content) → OpenAPI - Parses a JSON OpenAPI spec from a string. Throws FormatException if the content is not valid JSON.
-
parseYaml(
String content) → OpenAPI - Parses a YAML OpenAPI spec from a string. Throws a parsing error if the content is not valid YAML.
-
toJsonString(
OpenAPI spec) → String - Serializes a OpenAPI object to a formatted JSON string.