additionalProperties property
Specifies the schema for any additional properties in the object.
Implementation
Xml? get xml;/// Specifies the schema for any additional properties in the object.
Schema? get additionalProperties;
Specifies the schema for any additional properties in the object.
Xml? get xml;/// Specifies the schema for any additional properties in the object.
Schema? get additionalProperties;