properties property

Map<String, Schema>? get properties
inherited

A map of property names to their respective Schema objects.

Implementation

@JsonKey(name: 'required') List<String>? get $required;/// A map of property names to their respective [Schema] objects.
 Map<String, Schema>? get properties;