ref property
A reference to another Schema Object, typically in the components
section.
Implementation
@JsonKey(name: r'$ref') String? get ref;
A reference to another Schema Object, typically in the components
section.
@JsonKey(name: r'$ref') String? get ref;