toString method

  1. @override
String toString()
inherited

A string representation of this object.

Some classes have a default textual representation, often paired with a static parse function (like int.parse). These classes will provide the textual representation as their string representation.

Other classes have no meaningful textual representation that a program will care about. Such classes will typically override toString to provide useful information when inspecting the object, mainly for debugging or logging.

Implementation

@override
String toString() {
  return 'Schema(ref: $ref, type: $type, format: $format, title: $title, description: $description, \$required: ${$required}, properties: $properties, items: $items, example: $example, enumValues: $enumValues, \$default: ${$default}, xml: $xml, additionalProperties: $additionalProperties, maximum: $maximum, exclusiveMaximum: $exclusiveMaximum, minimum: $minimum, exclusiveMinimum: $exclusiveMinimum, externalDocs: $externalDocs, discriminator: $discriminator, allOf: $allOf, allowEmptyValue: $allowEmptyValue, collectionFormat: $collectionFormat, maxLength: $maxLength, minLength: $minLength, maxItems: $maxItems, minItems: $minItems, pattern: $pattern, uniqueItems: $uniqueItems, multipleOf: $multipleOf, \$deprecated: ${$deprecated})';
}