Discriminator constructor
- @JsonSerializable.new(includeIfNull: false, explicitToJson: true)
Creates a Discriminator object.
Implementation
@JsonSerializable(includeIfNull: false, explicitToJson: true)
const factory Discriminator({
/// The name of the property that is used to differentiate between schemas.
required String propertyName,
/// A map that associates a property value with a schema name.
Map<String, String>? mapping,
}) = _Discriminator;