style property

String? get style
inherited

Describes how a specific property value will be serialized.

Implementation

Map<String, Header> get headers;/// Describes how a specific property value will be serialized.
String? get style;