schema property
The schema defining the type used for the header.
Implementation
bool? get explode;/// The schema defining the type used for the header.
Schema? get schema;
The schema defining the type used for the header.
bool? get explode;/// The schema defining the type used for the header.
Schema? get schema;