parameters property
A map representing parameters to pass to an operation. The key is the parameter name, and the value is a constant or an expression.
Implementation
String? get operationId;/// A map representing parameters to pass to an operation. The key is the
/// parameter name, and the value is a constant or an expression.
Map<String, dynamic>? get parameters;