components property

Components? get components
inherited

An element to hold reusable objects for the specification.

Implementation

Map<String, PathItem> get paths;/// An element to hold reusable objects for the specification.
Components? get components;