servers property

List<Server> get servers
inherited

An array of Server Objects, which provide connectivity information to a target server.

Implementation

Info? get info;/// An array of Server Objects, which provide connectivity information
/// to a target server.
List<Server> get servers;