servers property

List<Server>? get servers
inherited

An alternative servers array to service all operations in this path. If a servers array is specified at the OpenAPI Object level, it will be overridden by this value.

Implementation

String? get description;/// An alternative servers array to service all operations in this path.
/// If a servers array is specified at the OpenAPI Object level,
/// it will be overridden by this value.
List<Server>? get servers;