content property

Map<String, MediaType> get content
inherited

The content of the request body, mapped by media type.

Implementation

@JsonKey(name: 'required') bool? get $required;/// The content of the request body, mapped by media type.
 Map<String, MediaType> get content;