links property

Map<String, Link>? get links
inherited

A map of operations links that can be followed from the response. The key of the map is a short name for the link, following the naming constraints of the names for Component Objects.

Implementation

Map<String, Header>? get headers;/// A map of operations links that can be followed from the response.
/// The key of the map is a short name for the link,
/// following the naming constraints of the names for Component Objects.
Map<String, Link>? get links;