$required property

  1. @JsonKey.new(name: 'required')
List<String>? get $required
inherited

A list of properties that must be present in the object.

Implementation

String? get description;/// A list of properties that must be present in the object.
@JsonKey(name: 'required') List<String>? get $required;