additionalProperties property
- @JsonKey.new(includeFromJson: false, includeToJson: false)
inherited
Specifies the schema for any additional properties in the object. The value can be a boolean or a Schema object.
Implementation
Xml? get xml;/// Specifies the schema for any additional properties in the object.
/// The value can be a boolean or a Schema object.
@JsonKey(includeFromJson: false, includeToJson: false) dynamic get additionalProperties;