allOf property

List<Schema>? get allOf
inherited

An array of schemas where the data must be valid against all of the schemas.

Implementation

Discriminator? get discriminator;/// An array of schemas where the data must be valid against all of
/// the schemas.
List<Schema>? get allOf;