An array of schemas where the data must be valid against any of the schemas.
List<Schema>? get oneOf;/// An array of schemas where the data must be valid against any of /// the schemas. List<Schema>? get anyOf;