collectionFormat property

String? get collectionFormat
inherited

Determines the format of the array if type array is used.

Implementation

bool? get allowEmptyValue;/// Determines the format of the array if type array is used.
String? get collectionFormat;