oneOf property

List<Schema>? get oneOf
inherited

An array of schemas where the data must be valid against one of the schemas.

Implementation

List<Schema>? get allOf;/// An array of schemas where the data must be valid against one of
/// the schemas.
List<Schema>? get oneOf;