Example class abstract

An object grouping an internal or external example value with basic summary and description metadata.

The value field and externalValue field are mutually exclusive.

Available extensions
Annotations
  • @freezed

Constructors

Example({String? summary, String? description, dynamic value, String? externalValue})
Creates an Example object.
const
factory
Example.fromJson(Map<String, dynamic> json)
Creates an Example from a JSON object.
factory

Properties

copyWith → $ExampleCopyWith<Example>
Create a copy of Example with the given fields replaced by the non-null parameter values.
no setterinherited
description String?
A long description for the example.
no setterinherited
externalValue String?
A URL that points to the literal example. The value field and externalValue field are mutually exclusive.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
summary String?
A short description for the example.
no setterinherited
value → dynamic
Embedded literal example. The value field and externalValue field are mutually exclusive.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_Example value)) → TResult

Available on Example, provided by the ExamplePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_Example value)?) → TResult?

Available on Example, provided by the ExamplePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_Example value)?, {required TResult orElse()}) → TResult

Available on Example, provided by the ExamplePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(String? summary, String? description, dynamic value, String? externalValue)?, {required TResult orElse()}) → TResult

Available on Example, provided by the ExamplePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this Example to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(String? summary, String? description, dynamic value, String? externalValue)) → TResult

Available on Example, provided by the ExamplePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(String? summary, String? description, dynamic value, String? externalValue)?) → TResult?

Available on Example, provided by the ExamplePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited