schema property

Schema? get schema
inherited

The schema defining the type used for the header.

Implementation

bool? get explode;/// The schema defining the type used for the header.
Schema? get schema;