servers property

List<Server>? get servers
inherited

An array of Server Objects, which provide connectivity information
to a target server.

Implementation

String get openapi;/// An array of Server Objects, which provide connectivity information \
/// to a target server.
List<Server>? get servers;