servers property

List<Server>? get servers
inherited

An alternative servers array to service this operation. If a servers array is specified at the Path Item Object or OpenAPI Object level, it will be overridden by this value.

Implementation

bool? get deprecated;/// An alternative servers array to service this operation.
/// If a servers array is specified at the Path Item Object or
/// OpenAPI Object level, it will be overridden by this value.
List<Server>? get servers;