parameters property

List<Parameter>? get parameters
inherited

A list of parameters that are applicable for all the operations described under this path. These parameters can be overridden at the operation level, but cannot be removed there. The list MUST NOT include duplicated parameters. A unique parameter is defined by a combination of a name and location. The list can use the Reference Object to link to parameters that are defined at the OpenAPI Object's components/parameters.

Implementation

List<Server>? get servers;/// A list of parameters that are applicable for all the operations
/// described under this path.
/// These parameters can be overridden at the operation level,
/// but cannot be removed there.
/// The list MUST NOT include duplicated parameters.
/// A unique parameter is defined by a combination of a name
/// and location.
/// The list can use the Reference Object to link to parameters
/// that are defined at the OpenAPI Object's components/parameters.
List<Parameter>? get parameters;