ref property

  1. @JsonKey.new(name: r'$ref')
String? get ref
inherited

A reference to a definition that contains the actual response content.

Implementation

@JsonKey(includeIfNull: false, includeFromJson: false, includeToJson: false) Map<String, dynamic>? get extensions;/// A reference to a definition that contains the actual response content.
@JsonKey(name: r'$ref') String? get ref;