additionalProperties property

dynamic get additionalProperties
inherited

Specifies the schema for any additional properties in the object.

Implementation

Xml? get xml;/// Specifies the schema for any additional properties in the object.
dynamic get additionalProperties;