items property

Schema? get items
inherited

For array types, this describes the type of items in the array.

Implementation

Map<String, Schema>? get properties;/// For array types, this describes the type of items in the array.
Schema? get items;