OAuthFlow class abstract

Represents the configuration details for a supported OAuth Flow.

Available extensions
Annotations
  • @freezed

Constructors

OAuthFlow({required Map<String, String> scopes, String? authorizationUrl, String? tokenUrl, String? refreshUrl})
Creates an OAuthFlow object.
const
factory
OAuthFlow.fromJson(Map<String, dynamic> json)
Creates an OAuthFlow from a JSON object.
factory

Properties

authorizationUrl String?
The authorization URL to be used for this flow.
no setterinherited
copyWith → $OAuthFlowCopyWith<OAuthFlow>
Create a copy of OAuthFlow with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
refreshUrl String?
The URL to be used for obtaining refresh tokens.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes Map<String, String>
The available scopes for the OAuth2 security scheme.
no setterinherited
tokenUrl String?
The token URL to be used for this flow.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_OAuthFlow value)) → TResult

Available on OAuthFlow, provided by the OAuthFlowPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_OAuthFlow value)?) → TResult?

Available on OAuthFlow, provided by the OAuthFlowPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_OAuthFlow value)?, {required TResult orElse()}) → TResult

Available on OAuthFlow, provided by the OAuthFlowPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(Map<String, String> scopes, String? authorizationUrl, String? tokenUrl, String? refreshUrl)?, {required TResult orElse()}) → TResult

Available on OAuthFlow, provided by the OAuthFlowPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this OAuthFlow to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(Map<String, String> scopes, String? authorizationUrl, String? tokenUrl, String? refreshUrl)) → TResult

Available on OAuthFlow, provided by the OAuthFlowPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(Map<String, String> scopes, String? authorizationUrl, String? tokenUrl, String? refreshUrl)?) → TResult?

Available on OAuthFlow, provided by the OAuthFlowPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited