bearerFormat property

String? get bearerFormat
inherited

A hint to the client to identify the bearer token format.

Implementation

String? get scheme;/// A hint to the client to identify the bearer token format.
String? get bearerFormat;