ServerVariable constructor

  1. @JsonSerializable.new(includeIfNull: false)
const ServerVariable({
  1. @JsonKey.new(name: 'default') required String defaultValue,
  2. @JsonKey.new(name: 'enum') List<String>? enumValues,
  3. String? description,
})

Creates a ServerVariable object.

Implementation

@JsonSerializable(includeIfNull: false)
const factory ServerVariable({
  /// REQUIRED. The default value to use for substitution, which SHALL be sent
  /// if an alternate value is not supplied.
  @JsonKey(name: 'default') required String defaultValue,

  /// An enumeration of string values to be used if the substitution
  /// options are from a limited set. The array MUST NOT be empty.
  @JsonKey(name: 'enum') List<String>? enumValues,

  /// An optional description for the server variable.
  String? description,
}) = _ServerVariable;