defaultValue property
REQUIRED. The default value to use for substitution, which SHALL be sent if an alternate value is not supplied.
Implementation
@JsonKey(name: 'default') String get defaultValue;
REQUIRED. The default value to use for substitution, which SHALL be sent if an alternate value is not supplied.
@JsonKey(name: 'default') String get defaultValue;