enumValues property
An enumeration of string values to be used if the substitution options are from a limited set. The array MUST NOT be empty.
Implementation
@JsonKey(name: 'default') String get defaultValue;/// An enumeration of string values to be used if the substitution
/// options are from a limited set. The array MUST NOT be empty.
@JsonKey(name: 'enum') List<String>? get enumValues;