email property
The email address of the contact person or organization.
Implementation
String? get url;/// The email address of the contact person or organization.
String? get email;
The email address of the contact person or organization.
String? get url;/// The email address of the contact person or organization.
String? get email;