securityDefinitions property
A declaration of security schemes used in the API.
Implementation
Map<String, Schema> get definitions;/// A declaration of security schemes used in the API.
Map<String, SecurityScheme> get securityDefinitions;
A declaration of security schemes used in the API.
Map<String, Schema> get definitions;/// A declaration of security schemes used in the API.
Map<String, SecurityScheme> get securityDefinitions;