Response class abstract
Describes a single API response.
This class represents a response definition in an OpenAPI document, including its description, content, and headers.
- Available extensions
- Annotations
-
- @Freezed.new(copyWith: true, fromJson: true, toJson: true, equal: true)
Constructors
Properties
-
content
→ Map<
String, MediaType> ? -
The content of the response for OpenAPI 3.0.
no setterinherited
-
copyWith
→ $ResponseCopyWith<
Response> -
Create a copy of Response
with the given fields replaced by the non-null parameter values.
no setterinherited
- description → String
-
A brief description of the response.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, Header> ? -
A map of headers for this response.
no setterinherited
- ref → String?
-
The reference to the response schema.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- schema → Schema?
-
The response schema for OpenAPI 2.0.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_Response value)) → TResult -
Available on Response, provided by the ResponsePatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_Response value)?) → TResult? -
Available on Response, provided by the ResponsePatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_Response value)?, {required TResult orElse()}) → TResult -
Available on Response, provided by the ResponsePatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(String description, Schema? schema, Map< String, MediaType> ? content, Map<String, Header> ? headers, String? ref)?, {required TResult orElse()}) → TResult -
Available on Response, provided by the ResponsePatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this Response to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(String description, Schema? schema, Map< String, MediaType> ? content, Map<String, Header> ? headers, String? ref)) → TResult -
Available on Response, provided by the ResponsePatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(String description, Schema? schema, Map< String, MediaType> ? content, Map<String, Header> ? headers, String? ref)?) → TResult? -
Available on Response, provided by the ResponsePatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited