A map of property names to their respective Schema objects.
@JsonKey(name: 'required') List<String>? get $required;/// A map of property names to their respective [Schema] objects. Map<String, Schema>? get properties;