style property
Describes how a specific property value will be serialized.
Implementation
Map<String, Header> get headers;/// Describes how a specific property value will be serialized.
String? get style;
Describes how a specific property value will be serialized.
Map<String, Header> get headers;/// Describes how a specific property value will be serialized.
String? get style;