Link constructor
- @JsonSerializable.new(includeIfNull: false)
Creates a Link object.
Implementation
@JsonSerializable(includeIfNull: false)
const factory Link({
/// A URI reference to an OAS operation. This field is mutually exclusive
/// with the [operationId] field.
String? operationRef,
/// The name of an existing, resolvable OAS operation, as defined with
/// a unique operationId. This field is mutually exclusive with the
/// [operationRef] field.
String? operationId,
/// A map representing parameters to pass to an operation. The key is the
/// parameter name, and the value is a constant or an expression.
Map<String, dynamic>? parameters,
/// A literal value or an expression to use as a request body when
/// calling the target operation.
dynamic requestBody,
/// A description of the link.
String? description,
/// A server object to be used by the target operation.
Server? server,
}) = _Link;