requestBody property
dynamic
get
requestBody
inherited
A literal value or an expression to use as a request body when calling the target operation.
Implementation
Map<String, dynamic>? get parameters;/// A literal value or an expression to use as a request body when
/// calling the target operation.
dynamic get requestBody;