items property
For array types, describes the type of items in the array (OpenAPI 2.0).
Implementation
String? get collectionFormat;/// For array types, describes the type of items in the array (OpenAPI 2.0).
Schema? get items;
For array types, describes the type of items in the array (OpenAPI 2.0).
String? get collectionFormat;/// For array types, describes the type of items in the array (OpenAPI 2.0).
Schema? get items;