collectionFormat property
Determines the format of the array if type array is used.
Implementation
bool? get allowEmptyValue;/// Determines the format of the array if type array is used.
String? get collectionFormat;
Determines the format of the array if type array is used.
bool? get allowEmptyValue;/// Determines the format of the array if type array is used.
String? get collectionFormat;