not property
A schema where the data must not be valid against this schema.
Implementation
List<Schema>? get anyOf;/// A schema where the data must not be valid against this schema.
Schema? get not;
A schema where the data must not be valid against this schema.
List<Schema>? get anyOf;/// A schema where the data must not be valid against this schema.
Schema? get not;