headers property
A map allowing additional information to be provided as headers. This field is ignored if the request body media type is not a multipart.
Implementation
String? get contentType;/// A map allowing additional information to be provided as headers.
/// This field is ignored if the request body media type is not a multipart.
Map<String, Header> get headers;