identifier property
An SPDX license expression for the API. The identifier field is mutually exclusive of the url field.
Implementation
String get name;/// An SPDX license expression for the API.
/// The identifier field is mutually exclusive of the url field.
String? get identifier;