openapi property
This string MUST be the semantic version number of the OpenAPI Specification version that the OpenAPI document uses.
Implementation
Info get info;/// This string MUST be the semantic version number of the OpenAPI
/// Specification version that the OpenAPI document uses.
String get openapi;