security property
A declaration of which security schemes are applied to the API as a whole.
Implementation
String? get jsonSchemaDialect;/// A declaration of which security schemes are applied to the API
/// as a whole.
List<SecurityRequirement> get security;