An array of Server Objects, which provide connectivity information to a target server.
String get openapi;/// An array of Server Objects, which provide connectivity information \ /// to a target server. List<Server>? get servers;