description property
An optional string description, intended to apply to all operations in this path. CommonMark syntax MAY be used for rich text representation.
Implementation
String? get summary;/// An optional string description,
/// intended to apply to all operations in this path.
/// CommonMark syntax MAY be used for rich text representation.
String? get description;