summary property
An optional string summary, intended to apply to all operations in this path.
Implementation
@JsonKey(name: r'$ref') String? get ref;/// An optional string summary,
/// intended to apply to all operations in this path.
String? get summary;