items property
For array types, this describes the type of items in the array.
Implementation
Map<String, Schema>? get properties;/// For array types, this describes the type of items in the array.
Schema? get items;
For array types, this describes the type of items in the array.
Map<String, Schema>? get properties;/// For array types, this describes the type of items in the array.
Schema? get items;