OAuthFlow class abstract
Represents the configuration details for a supported OAuth Flow.
- Available extensions
- Annotations
-
- @freezed
Constructors
Properties
-
The authorization URL to be used for this flow.
no setterinherited
-
copyWith
→ $OAuthFlowCopyWith<
OAuthFlow> -
Create a copy of OAuthFlow
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- refreshUrl → String?
-
The URL to be used for obtaining refresh tokens.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
scopes
→ Map<
String, String> -
The available scopes for the OAuth2 security scheme.
no setterinherited
- tokenUrl → String?
-
The token URL to be used for this flow.
no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_OAuthFlow value)) → TResult -
Available on OAuthFlow, provided by the OAuthFlowPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_OAuthFlow value)?) → TResult? -
Available on OAuthFlow, provided by the OAuthFlowPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_OAuthFlow value)?, {required TResult orElse()}) → TResult -
Available on OAuthFlow, provided by the OAuthFlowPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(Map< String, String> scopes, String? authorizationUrl, String? tokenUrl, String? refreshUrl)?, {required TResult orElse()}) → TResult -
Available on OAuthFlow, provided by the OAuthFlowPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this OAuthFlow to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(Map< String, String> scopes, String? authorizationUrl, String? tokenUrl, String? refreshUrl)) → TResult -
Available on OAuthFlow, provided by the OAuthFlowPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(Map< String, String> scopes, String? authorizationUrl, String? tokenUrl, String? refreshUrl)?) → TResult? -
Available on OAuthFlow, provided by the OAuthFlowPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited