SecurityScheme constructor
- @JsonSerializable.new(includeIfNull: false, explicitToJson: true)
- required String type,
- String? description,
- String? name,
- @JsonKey.new(name: 'in') ParameterLocation? location,
- String? scheme,
- String? bearerFormat,
- OAuthFlows? flows,
- String? openIdConnectUrl,
- @JsonKey.new(includeIfNull: false, includeFromJson: false, includeToJson: false) Map<
String, dynamic> ? extensions,
Creates a SecurityScheme object.
Implementation
@JsonSerializable(includeIfNull: false, explicitToJson: true)
const factory SecurityScheme({
/// The type of the security scheme.
required String type,
/// A short description of the security scheme.
String? description,
/// The name of the header, query, or cookie parameter to be used.
String? name,
/// The location of the API key.
@JsonKey(name: 'in') ParameterLocation? location,
/// The name of the HTTP Authentication scheme.
String? scheme,
/// A hint to the client to identify the bearer token format.
String? bearerFormat,
/// Configuration information for the flow types supported.
OAuthFlows? flows,
/// Well-known URL to discover the OpenID Connect provider metadata.
String? openIdConnectUrl,
/// Vendor extensions (keys like `x-*`).
@JsonKey(includeIfNull: false, includeFromJson: false, includeToJson: false)
Map<String, dynamic>? extensions,
}) = _SecurityScheme;