ServerVariable constructor
- @JsonSerializable.new(includeIfNull: false)
Creates a ServerVariable object.
Implementation
@JsonSerializable(includeIfNull: false)
const factory ServerVariable({
/// REQUIRED. The default value to use for substitution, which SHALL be sent
/// if an alternate value is not supplied.
@JsonKey(name: 'default') required String defaultValue,
/// An enumeration of string values to be used if the substitution
/// options are from a limited set. The array MUST NOT be empty.
@JsonKey(name: 'enum') List<String>? enumValues,
/// An optional description for the server variable.
String? description,
}) = _ServerVariable;